@@ -54,7 +54,9 @@ def guess_format(filename):
     formats['osrl']=ResultsFormat.osrl
     formats['soln']=ResultsFormat.soln
     formats['yml']=ResultsFormat.yaml
+    formats['yaml']=ResultsFormat.yaml
     formats['jsn']=ResultsFormat.json
+    formats['json']=ResultsFormat.json
     formats['results']=ResultsFormat.yaml
     for fmt in formats:
         if filename.endswith('.'+fmt):
