@@ -150,7 +150,14 @@ The original solver was created with the following parameters:
 + "\n\toptions: %s" % ( self.options, )
 + "\n\t_options_str: %s" % ( self._options_str, ) )
 
+
+#
+# A SolverFactory is an instance of a plugin factory that is 
+# customized with a custom __call__ method
 SolverFactory = CreatePluginFactory(IOptSolver)
+#
+# This is the custom __call__ method
+#
 def __solver_call__(self, _name=None, args=[], **kwds):
     if _name is None:
         return self
@@ -205,6 +212,9 @@ should include the line, "import coopr.environ".""" )
         opt = UnknownSolver( type=_name, *args, **kwds )
         opt.name = _name
     return opt
+#
+# Adding the the custom __call__ method to SolverFactory
+#
 pyutilib.misc.add_method(SolverFactory, __solver_call__, name='__call__')
 
 #
@@ -293,6 +303,7 @@ class OptSolver(Plugin):
         self._valid_result_formats={}
         self.results_reader=None
         self.problem=None
+        self._problem_files=None
         self._assert_available=False
         self._report_timing = False # timing statistics are always collected, but optionally reported.
         self.suffixes = [] # a list of the suffixes the user has request be loaded in a solution.
@@ -385,6 +396,7 @@ class OptSolver(Plugin):
 
     def solve(self, *args, **kwds):
         """ Solve the problem """
+        self.available(exception_flag=True)
         from coopr.pyomo.base import Block
         from coopr.pyomo.base.suffix import Suffix, active_import_suffix_generator
         #
@@ -481,7 +493,8 @@ class OptSolver(Plugin):
                 raise ValueError("Unknown option="+key+" for solver="+self.type)
         self.available()
 
-        (self._problem_files,self._problem_format,self._symbol_map) = self._convert_problem(args, self._problem_format, self._valid_problem_formats)
+        if self._problem_format:
+            (self._problem_files,self._problem_format,self._symbol_map) = self._convert_problem(args, self._problem_format, self._valid_problem_formats)
         if using_py3:
             compare_type = str
         else:
