@@ -9,7 +9,5 @@
 #  _________________________________________________________________________
 
 from coopr.opt.blackbox.point import *
-import coopr.opt.blackbox.colin_xml_io
-import coopr.opt.blackbox.dakota_text_io
 from coopr.opt.blackbox.problem import *
 import coopr.opt.blackbox.solver
