@@ -11,7 +11,7 @@
 
 __all__ = []
 
-from pyutilib.component.core import alias
+from coopr.core.plugin import alias
 
 import coopr.opt
 from coopr.opt.parallel.manager import *
