@@ -41,7 +41,7 @@ class SolverResults(MapContainer):
     undefined = undefined
     default_print_options = dpo
 
-    def __del__(self):
+    def X__del__(self):
         MapContainer.__del__(self)
         self._sections = None
         self._descriptions = None
