@@ -23,11 +23,18 @@ except ImportError:
     import pickle
 import datetime
 import pyutilib.services
-import pyutilib.pyro
+try:
+    pyro_available=True
+    from pyutilib.pyro import TaskWorker
+    from pyutilib.pyro import TaskWorkerServer
+except:
+    pyro_available=False
+    class TaskWorker(object): pass
+    class TaskWorkerServer(object): pass
 from coopr.core import coopr_command
 
 
-class CooprMIPWorker(pyutilib.pyro.TaskWorker):
+class CooprMIPWorker(TaskWorker):
 
     def process(self, data):
         import coopr.opt
@@ -91,13 +98,19 @@ class CooprMIPWorker(pyutilib.pyro.TaskWorker):
 @coopr_command('pyro_mip_server', "Launch a Pyro server for Coopr MIP solvers")
 def main():
     #
+    # Handle error when pyro is not installed
+    #
+    if not pyro_available:
+        print("ERROR: Aborting the pyro_mip_server.  The 'pyro' package is not installed.")
+        return
+    #
     # Import plugins
     #
     import coopr.environ
     #
     exception_trapped = False
     try:
-        pyutilib.pyro.TaskWorkerServer(CooprMIPWorker, argv=sys.argv)
+        TaskWorkerServer(CooprMIPWorker, argv=sys.argv)
     except IOError:
         msg = sys.exc_info()[1]
         print("IO ERROR:")
