@@ -11,19 +11,21 @@
 __all__ = ['TestCase']
 
 import os
-import pyutilib.th as unittest
 import copy
-import pyutilib.subprocess
-from coopr.opt import SolverResults
 import re
-import pyutilib.misc
-from inspect import getfile
-
 try:
     import yaml
     using_yaml=True
 except ImportError:
     using_yaml=False
+from inspect import getfile
+
+import pyutilib.th as unittest
+import pyutilib.subprocess
+import pyutilib.misc
+
+from coopr.opt import SolverResults
+
 
 def _failIfCooprResultsDiffer(self, cmd=None, baseline=None, cwd=None):
     if cwd is None:
@@ -47,10 +49,12 @@ def _failIfCooprResultsDiffer(self, cmd=None, baseline=None, cwd=None):
     results = extract_results( re.split('\n',output[1]) )
     try:
         compare_results(results, baseline)
-    except IOError, err:
-        self.fail("Command failed to generate results that can be compared with the baseline: '%s'" % str(err))
-    except ValueError, err:
-        self.fail("Difference between results and baseline: '%s'" % str(err))
+    except IOError:
+        err = sys.exc_info()[1]
+        self.fail("Command failed to generate results that can be compared with the baseline: '%s'" % err)
+    except ValueError:
+        err = sys.exc_info()[1]
+        self.fail("Difference between results and baseline: '%s'" % err)
 
 
 class TestCase(unittest.TestCase):
@@ -68,10 +72,10 @@ class TestCase(unittest.TestCase):
         if not using_yaml:
             return
         if cmd is None and fn is None:
-            print "ERROR: must specify either the 'cmd' or 'fn' option to define how the output file is generated"
+            print("ERROR: must specify either the 'cmd' or 'fn' option to define how the output file is generated")
             return
         if name is None and baseline is None:
-            print "ERROR: must specify a baseline comparison file, or the test name"
+            print("ERROR: must specify a baseline comparison file, or the test name")
             return
         if baseline is None:
             baseline=name+".txt"
