@@ -26,6 +26,7 @@ try:
 except ImportError:
     yaml_available=False
 
+old_tempdir = pyutilib.services.TempfileManager.tempdir
 
 class Test(unittest.TestCase):
 
@@ -36,9 +37,10 @@ class Test(unittest.TestCase):
         self.soln.variable[1]={"Value" : 0, "Id" : 0}
         self.soln.variable[2]={"Value" : 0, "Id" : 1}
         self.soln.variable[4]={"Value" : 0, "Id" : 2}
-        pyutilib.services.TempfileManager.clear_tempfiles()
 
     def tearDown(self):
+        pyutilib.services.TempfileManager.clear_tempfiles()
+        pyutilib.services.TempfileManager.tempdir = old_tempdir
         del self.results
 
     def test_write_solution1(self):
