@@ -15,8 +15,9 @@ from nose.tools import nottest
 import coopr.opt
 import coopr
 import pyutilib.services
-from pyutilib.component.core import alias
+from coopr.core.plugin import alias
 
+old_tempdir = pyutilib.services.TempfileManager.tempdir
 
 class TestSolver1(coopr.opt.OptSolver):
 
@@ -39,6 +40,7 @@ class OptSolverDebug(unittest.TestCase):
 
     def tearDown(self):
         pyutilib.services.TempfileManager.clear_tempfiles()
+        pyutilib.services.TempfileManager.tempdir = old_tempdir
 
 
     def test_solver_init1(self):
